@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -23,13 +23,9 @@ our $ObjectManagerDisabled = 1;
 sub new {
     my ( $Type, %Param ) = @_;
 
-    # allocate new hash for object
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # check if cloud services are disabled
-    $Self->{CloudServicesDisabled} = $Kernel::OM->Get('Kernel::Config')->Get('CloudServices::Disabled') || 0;
-
     return $Self;
 }
 
@@ -61,7 +57,7 @@ sub Run {
                 if ( !$ApacheReload ) {
                     return $LayoutObject->ErrorScreen(
                         Message => Translatable(
-                            'Sorry, Apache::Reload is needed as PerlModule and PerlInitHandler in Apache config file. See also scripts/apache2-httpd.include.conf. Alternatively, you can use the command line tool bin/otrs.Console.pl to install packages!'
+                            'Sorry, Apache::Reload is needed as PerlModule and PerlInitHandler in Apache config file. See also scripts/apache2-httpd.include.conf. Alternatively, you can use the command line tool bin/znuny.Console.pl to install packages!'
                         ),
                     );
                 }
@@ -143,6 +139,7 @@ sub Run {
             if ($Content) {
                 $MainObject->Require('Text::Diff');
                 my $Diff = Text::Diff::diff( \$File, $Content, { STYLE => 'OldStyle' } );
+                $Kernel::OM->Get('Kernel::System::Encode')->EncodeInput( \$Diff );
                 $LayoutObject->Block(
                     Name => "FileDiff",
                     Data => {
@@ -200,20 +197,6 @@ sub Run {
         # parse package
         my %Structure = $PackageObject->PackageParse( String => $Package );
 
-        # online verification
-        my $Verified = $PackageObject->PackageVerify(
-            Package   => $Package,
-            Structure => \%Structure,
-        ) || 'unknown';
-        my %VerifyInfo = $PackageObject->PackageVerifyInfo();
-
-        # translate description
-        if ( $LayoutObject->{LanguageObject} ) {
-            $VerifyInfo{Description} = $LayoutObject->{LanguageObject}->Translate(
-                $VerifyInfo{Description}
-            );
-        }
-
         # deploy check
         my $Deployed = $PackageObject->DeployCheck(
             Name    => $Name,
@@ -456,7 +439,6 @@ sub Run {
                                         Version => $Version,
                                         %{$Hash},
                                         Message => $DeployInfo{File}->{ $Hash->{Location} },
-                                        Icon    => 'IconNotReady',
                                     },
                                 );
                             }
@@ -467,8 +449,6 @@ sub Run {
                                         Name    => $Name,
                                         Version => $Version,
                                         %{$Hash},
-                                        Message => $DeployInfo{File}->{ $Hash->{Location} },
-                                        Icon    => 'IconNotReadyGrey',
                                     },
                                 );
                             }
@@ -480,8 +460,6 @@ sub Run {
                                     Name    => $Name,
                                     Version => $Version,
                                     %{$Hash},
-                                    Message => Translatable('File is OK'),
-                                    Icon    => 'IconReady',
                                 },
                             );
                         }
@@ -520,17 +498,6 @@ sub Run {
             );
         }
 
-        if ( $Verified ne 'verified' ) {
-
-            $Output .= $LayoutObject->Notify(
-                Priority => 'Error',
-                Data     => "$Name $Version - "
-                    . $LayoutObject->{LanguageObject}->Translate(
-                    "Package not verified by the OTRS Group! It is recommended not to use this package."
-                    ),
-            );
-        }
-
         $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminPackageManager',
         );
@@ -557,11 +524,6 @@ sub Run {
                 Message => Translatable('No such package!'),
             );
         }
-        elsif ( substr( $Package, 0, length('ErrorMessage:') ) eq 'ErrorMessage:' ) {
-
-            # an error from the Package::CloudFileGet function
-            return $LayoutObject->ErrorScreen( Message => $Package );
-        }
         my %Structure = $PackageObject->PackageParse( String => $Package );
 
         $Frontend{Name} = $Structure{Name}->{Content};
@@ -1524,38 +1486,18 @@ sub Run {
     # ------------------------------------------------------------ #
     my %Frontend;
     my %NeedReinstall;
-    my %List;
     my $OutputNotify = '';
-    if ( $ConfigObject->Get('Package::RepositoryList') ) {
-        %List = %{ $ConfigObject->Get('Package::RepositoryList') };
-    }
-    my %RepositoryRoot;
-    if ( $ConfigObject->Get('Package::RepositoryRoot') ) {
-        %RepositoryRoot = $PackageObject->PackageOnlineRepositories();
-    }
 
-    # show cloud repo if system is registered
-    my $RepositoryCloudList;
-    my $RegistrationState = $Kernel::OM->Get('Kernel::System::SystemData')->SystemDataGet(
-        Key => 'Registration::State',
-    ) || '';
-    if ( $RegistrationState eq 'registered' && !$Self->{CloudServicesDisabled} ) {
-
-        $RepositoryCloudList =
-            $PackageObject->RepositoryCloudList( NoCache => 1 );
-    }
-
-    # In case Source is present on repository cloud list
-    #   the call for retrieving data about it, should be performed
-    #   using the CloudService backend.
-    my $FromCloud = ( $RepositoryCloudList->{$Source} ? 1 : 0 );
+    my %RepositoryList = $PackageObject->ConfiguredRepositoryListGet();
 
     # Get the list of the installed packages early to be able to show or not the Upgrade All button
     #   in the layout block.
     my @RepositoryList = $PackageObject->RepositoryList();
 
+    my %RepositoryListSelection = map { $_ => $_ } keys %RepositoryList;
+
     $Frontend{SourceList} = $LayoutObject->BuildSelection(
-        Data        => { %List, %RepositoryRoot, %{$RepositoryCloudList}, },
+        Data        => \%RepositoryListSelection,
         Name        => 'Source',
         Title       => Translatable('Repository List'),
         Max         => 40,
@@ -1573,10 +1515,9 @@ sub Run {
     );
     if ($Source) {
 
-        my @List = $PackageObject->PackageOnlineList(
-            URL       => $Source,
-            Lang      => $LayoutObject->{UserLanguage},
-            FromCloud => $FromCloud,
+        my @List = $PackageObject->RepositoryPackageListGet(
+            Source => $Source,
+            Lang   => $LayoutObject->{UserLanguage},
         );
         if ( !@List ) {
             $OutputNotify .= $LayoutObject->Notify(
@@ -1659,17 +1600,7 @@ sub Run {
         );
     }
 
-    # verify packages if we have some
-    my %VerificationData;
-    if (@RepositoryList) {
-        %VerificationData = $PackageObject->PackageVerifyAll();
-    }
-
-    my %NotVerifiedPackages;
-    my %UnknownVerficationPackages;
-
     for my $Package (@RepositoryList) {
-
         my %Data = $Self->_MessageGet( Info => $Package->{Description} );
 
         $LayoutObject->Block(
@@ -1684,17 +1615,6 @@ sub Run {
             },
         );
 
-        if (
-            $VerificationData{ $Package->{Name}->{Content} }
-            && $VerificationData{ $Package->{Name}->{Content} } eq 'verified'
-            && !$Self->{CloudServicesDisabled}
-            )
-        {
-            $LayoutObject->Block(
-                Name => 'ShowLocalPackageVerifyLogo',
-            );
-        }
-
         # show documentation link
         my %DocFile = $Self->_DocumentationGet( Filelist => $Package->{Filelist} );
         if (%DocFile) {
@@ -1709,7 +1629,6 @@ sub Run {
         }
 
         if ( $Package->{Status} eq 'installed' ) {
-
             if (
                 !defined $Package->{PackageIsRemovable}
                 || (
@@ -1718,7 +1637,6 @@ sub Run {
                 )
                 )
             {
-
                 $LayoutObject->Block(
                     Name => 'ShowLocalPackageUninstall',
                     Data => {
@@ -1763,22 +1681,6 @@ sub Run {
                 },
             );
         }
-
-        if (
-            $VerificationData{ $Package->{Name}->{Content} }
-            && $VerificationData{ $Package->{Name}->{Content} } eq 'not_verified'
-            )
-        {
-            $NotVerifiedPackages{ $Package->{Name}->{Content} } = $Package->{Version}->{Content};
-        }
-        elsif (
-            $VerificationData{ $Package->{Name}->{Content} }
-            && $VerificationData{ $Package->{Name}->{Content} } eq 'unknown'
-            )
-        {
-            $UnknownVerficationPackages{ $Package->{Name}->{Content} } = $Package->{Version}->{Content};
-        }
-
     }
 
     # show file upload
@@ -1820,34 +1722,6 @@ sub Run {
         }
     }
 
-    # FeatureAddons
-    if ( $ConfigObject->Get('Package::ShowFeatureAddons') ) {
-
-        my $FeatureAddonData;
-        if ( !$Self->{CloudServicesDisabled} ) {
-            $FeatureAddonData = $Self->_GetFeatureAddonData();
-        }
-
-        if ( ref $FeatureAddonData eq 'ARRAY' && scalar @{$FeatureAddonData} > 0 ) {
-            $LayoutObject->Block(
-                Name => 'FeatureAddonList',
-            );
-
-            for my $Item ( @{$FeatureAddonData} ) {
-                $LayoutObject->Block(
-                    Name => 'FeatureAddonData',
-                    Data => $Item,
-                );
-            }
-        }
-    }
-
-    if ( $Self->{CloudServicesDisabled} ) {
-        $LayoutObject->Block(
-            Name => 'CloudServicesWarning',
-        );
-    }
-
     # Check if OTRS Daemon is running in the background.
     #   Get daemon state from the cache.
     my $DaemonRunning = $Kernel::OM->Get('Kernel::System::Cache')->Get(
@@ -1902,39 +1776,6 @@ sub Run {
         );
     }
 
-    VERIFICATION:
-    for my $Package ( sort keys %NotVerifiedPackages ) {
-
-        next VERIFICATION if !$Package;
-        next VERIFICATION if !$NotVerifiedPackages{$Package};
-
-        $Output .= $LayoutObject->Notify(
-            Priority => 'Error',
-            Data     => "$Package $NotVerifiedPackages{$Package} - "
-                . $LayoutObject->{LanguageObject}->Translate(
-                "Package not verified by the OTRS Group! It is recommended not to use this package."
-                ),
-        );
-    }
-
-    if ( !$Self->{CloudServicesDisabled} ) {
-
-        VERIFICATION:
-        for my $Package ( sort keys %UnknownVerficationPackages ) {
-
-            next VERIFICATION if !$Package;
-            next VERIFICATION if !$UnknownVerficationPackages{$Package};
-
-            $Output .= $LayoutObject->Notify(
-                Priority => 'Error',
-                Data     => "$Package $UnknownVerficationPackages{$Package} - "
-                    . $LayoutObject->{LanguageObject}->Translate(
-                    "Package not verified due a communication issue with verification server!"
-                    ),
-            );
-        }
-    }
-
     $Output .= $LayoutObject->Output(
         TemplateFile => 'AdminPackageManager',
     );
@@ -2080,72 +1921,13 @@ sub _InstallHandling {
         return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
     }
 
-    my $IntroInstallPre    = $ParamObject->GetParam( Param => 'IntroInstallPre' )    || '';
-    my $IntroInstallVendor = $ParamObject->GetParam( Param => 'IntroInstallVendor' ) || '';
+    my $IntroInstallPre = $ParamObject->GetParam( Param => 'IntroInstallPre' ) // '';
 
     my $PackageObject = $Kernel::OM->Get('Kernel::System::Package');
 
     # parse package
     my %Structure = $PackageObject->PackageParse( String => $Param{Package} );
 
-    # online verification
-    my $Verified = $PackageObject->PackageVerify(
-        Package   => $Param{Package},
-        Structure => \%Structure,
-    ) || 'verified';
-    my %VerifyInfo = $PackageObject->PackageVerifyInfo();
-
-    # translate description
-    if ( $LayoutObject->{LanguageObject} ) {
-        $VerifyInfo{Description} = $LayoutObject->{LanguageObject}->Translate(
-            $VerifyInfo{Description},
-            $VerifyInfo{PackageInstallPossible} ? '' : $LayoutObject->{Baselink},
-        );
-    }
-
-    # vendor screen
-    if ( !$IntroInstallVendor && !$IntroInstallPre && $Verified ne 'verified' ) {
-
-        $LayoutObject->Block(
-            Name => 'Intro',
-            Data => {
-                %Param,
-                %VerifyInfo,
-                Subaction => $Self->{Subaction},
-                Type      => 'IntroInstallVendor',
-                Name      => $Structure{Name}->{Content},
-                Version   => $Structure{Version}->{Content},
-            },
-        );
-
-        if ( $VerifyInfo{PackageInstallPossible} ) {
-
-            $LayoutObject->Block(
-                Name => 'IntroForm',
-                Data => {
-                    %Param,
-                    %VerifyInfo,
-                    Subaction => $Self->{Subaction},
-                    Type      => 'IntroInstallVendor',
-                    Name      => $Structure{Name}->{Content},
-                    Version   => $Structure{Version}->{Content},
-                },
-            );
-
-            $LayoutObject->Block(
-                Name => 'IntroCancel',
-            );
-        }
-
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Output(
-            TemplateFile => 'AdminPackageManager',
-        );
-        $Output .= $LayoutObject->Footer();
-        return $Output;
-    }
-
     # intro screen
     my %Data;
     if ( $Structure{IntroInstall} ) {
@@ -2155,17 +1937,20 @@ sub _InstallHandling {
         );
     }
 
-    # get cloud repositories
-    my $RepositoryCloudList;
-    if ( !$Self->{CloudServicesDisabled} ) {
-        $RepositoryCloudList = $PackageObject->RepositoryCloudList();
+    # parse sopm-file and show <PackageRequired> information
+    if ( $Structure{PackageRequired} ) {
+        $Data{PackageRequired} = $PackageObject->GetRequiredPackages(
+            Structure => \%Structure,
+        );
+        $Data{PackageRequiredProblem} = grep { $_->{IsInstalled} eq 0 } @{ $Data{PackageRequired} };
     }
 
-    # in case Source is present on repository cloud list
-    # the package should be retrieved using the CloudService backend
-    my $FromCloud = 0;
-    if ( $Param{Source} && $RepositoryCloudList->{ $Param{Source} } ) {
-        $FromCloud = 1;
+    # parse sopm-file and show <ModuleRequired> information
+    if ( $Structure{ModuleRequired} ) {
+        $Data{ModuleRequired} = $PackageObject->GetRequiredModules(
+            Structure => \%Structure,
+        );
+        $Data{ModuleRequiredProblem} = grep { $_->{IsInstalled} eq 0 } @{ $Data{ModuleRequired} };
     }
 
     my %Response = $PackageObject->AnalyzePackageFrameworkRequirements(
@@ -2214,12 +1999,6 @@ sub _InstallHandling {
             },
         );
 
-        if ( $Verified eq 'verified' && !$Self->{CloudServicesDisabled} ) {
-            $LayoutObject->Block(
-                Name => 'OTRSVerifyLogo',
-            );
-        }
-
         $LayoutObject->Block(
             Name => 'IntroForm',
             Data => {
@@ -2248,8 +2027,7 @@ sub _InstallHandling {
     # install package
     elsif (
         $PackageObject->PackageInstall(
-            String    => $Param{Package},
-            FromCloud => $FromCloud
+            String => $Param{Package},
         )
         )
     {
@@ -2287,12 +2065,6 @@ sub _InstallHandling {
                 },
             );
 
-            if ( $Verified eq 'verified' ) {
-                $LayoutObject->Block(
-                    Name => 'OTRSVerifyLogo',
-                );
-            }
-
             my $Output = $LayoutObject->Header();
             $Output .= $LayoutObject->NavigationBar();
             $Output .= $LayoutObject->Output(
@@ -2346,6 +2118,20 @@ sub _UpgradeHandling {
         );
     }
 
+    # parse sopm-file and show <PackageRequired> information
+    if ( $Structure{PackageRequired} ) {
+        $Data{PackageRequired} = $PackageObject->GetRequiredPackages(
+            Structure => \%Structure,
+        );
+    }
+
+    # parse sopm-file and show <ModuleRequired> information
+    if ( $Structure{ModuleRequired} ) {
+        $Data{ModuleRequired} = $PackageObject->GetRequiredModules(
+            Structure => \%Structure,
+        );
+    }
+
     my %Response = $PackageObject->AnalyzePackageFrameworkRequirements(
         Framework => $Structure{Framework},
         NoLog     => 1,
@@ -2466,82 +2252,6 @@ sub _UpgradeHandling {
     return $LayoutObject->ErrorScreen();
 }
 
-sub _GetFeatureAddonData {
-    my ( $Self, %Param ) = @_;
-
-    my $Language = $Kernel::OM->Get('Kernel::Output::HTML::Layout')->{UserLanguage};
-
-    # cleanup main language for languages like es_MX (es in this case)
-    $Language = substr $Language, 0, 2;
-
-    my $CacheKey  = "FeatureAddonData::$Language";
-    my $CacheTTL  = 60 * 60 * 24;                    # 1 day
-    my $CacheType = 'PackageManager';
-
-    my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
-    my $CacheResult = $CacheObject->Get(
-        Type => $CacheType,
-        Key  => $CacheKey,
-    );
-
-    return $CacheResult if ref $CacheResult eq 'ARRAY';
-
-    my $CloudService = 'PublicFeeds';
-    my $Operation    = 'FAOFeed';
-
-    # prepare cloud service request
-    my %RequestParams = (
-        RequestData => {
-            $CloudService => [
-                {
-                    Operation => $Operation,
-                    Data      => {
-                        Language => $Language,
-                    },
-                },
-            ],
-        },
-    );
-
-    my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService::Backend::Run');
-
-    # dispatch the cloud service request
-    my $RequestResult = $CloudServiceObject->Request(%RequestParams);
-
-    # as this is the only operation an unsuccessful request means that the operation was also
-    # unsuccessful
-    if ( !IsHashRefWithData($RequestResult) ) {
-        return Translatable('Can\'t connect to OTRS Feature Add-on list server!');
-    }
-
-    my $OperationResult = $CloudServiceObject->OperationResultGet(
-        RequestResult => $RequestResult,
-        CloudService  => $CloudService,
-        Operation     => $Operation,
-    );
-
-    if ( !IsHashRefWithData($OperationResult) ) {
-        return Translatable('Can\'t get OTRS Feature Add-on list from server!');
-    }
-    elsif ( !$OperationResult->{Success} ) {
-        return $OperationResult->{ErrorMessage} || Translatable('Can\'t get OTRS Feature Add-on from server!');
-    }
-
-    my $FAOFeed = $OperationResult->{Data}->{FAOs};
-
-    return if !IsArrayRefWithData($FAOFeed);
-
-    # set cache
-    $CacheObject->Set(
-        Type  => $CacheType,
-        Key   => $CacheKey,
-        Value => $FAOFeed,
-        TTL   => $CacheTTL,
-    );
-
-    return $FAOFeed;
-}
-
 sub _GetSafeString {
     my ( $Self, %Param ) = @_;
 
