@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -23,7 +23,6 @@ our @ObjectDependencies = (
     'Kernel::System::Log',
     'Kernel::System::Main',
     'Kernel::System::StandardTemplate',
-    'Kernel::System::SysConfig',
     'Kernel::System::Valid',
 );
 
@@ -642,10 +641,10 @@ get Follow-Up Option list
 Return:
 
     %FollowUpOptionList = (
-              '1' => 'possible',
-              '3' => 'new ticket',
-              '2' => 'reject'
-            )
+        '1' => 'possible',
+        '3' => 'new ticket',
+        '2' => 'reject',
+    )
 
 =cut
 
@@ -863,40 +862,27 @@ sub QueueAdd {
         Type => $Self->{CacheType},
     );
 
-    my $StandardTemplate2QueueByCreating = $ConfigObject->Get('StandardTemplate2QueueByCreating');
-
     # add default responses (if needed), add response by name
-    if (
-        $StandardTemplate2QueueByCreating
-        && ref $StandardTemplate2QueueByCreating eq 'ARRAY'
-        && @{$StandardTemplate2QueueByCreating}
-        )
-    {
+    my $StandardTemplateObject           = $Kernel::OM->Get('Kernel::System::StandardTemplate');
+    my $StandardTemplate2QueueByCreating = $ConfigObject->Get('StandardTemplate2QueueByCreating') // [];
 
-        # get standard template object
-        my $StandardTemplateObject = $Kernel::OM->Get('Kernel::System::StandardTemplate');
+    ST:
+    for my $ST ( @{$StandardTemplate2QueueByCreating} ) {
 
-        ST:
-        for my $ST ( @{$StandardTemplate2QueueByCreating} ) {
+        my $StandardTemplateID = $StandardTemplateObject->StandardTemplateLookup(
+            StandardTemplate => $ST,
+        );
 
-            my $StandardTemplateID = $StandardTemplateObject->StandardTemplateLookup(
-                StandardTemplate => $ST,
-            );
+        next ST if !$StandardTemplateID;
 
-            next ST if !$StandardTemplateID;
-
-            $Self->QueueStandardTemplateMemberAdd(
-                QueueID            => $QueueID,
-                StandardTemplateID => $StandardTemplateID,
-                Active             => 1,
-                UserID             => $Param{UserID},
-            );
-        }
+        $Self->QueueStandardTemplateMemberAdd(
+            QueueID            => $QueueID,
+            StandardTemplateID => $StandardTemplateID,
+            Active             => 1,
+            UserID             => $Param{UserID},
+        );
     }
 
-    # get standard template id
-    my $StandardTemplateID2QueueByCreating = $ConfigObject->Get(' StandardTemplate2QueueByCreating');
-
     # get queue data with updated name for QueueCreate event
     my %Queue = $Self->QueueGet( Name => $Param{Name} );
 
@@ -909,21 +895,6 @@ sub QueueAdd {
         UserID => $Param{UserID},
     );
 
-    return $QueueID if !$StandardTemplateID2QueueByCreating;
-    return $QueueID if ref $StandardTemplateID2QueueByCreating ne 'ARRAY';
-    return $QueueID if !@{$StandardTemplateID2QueueByCreating};
-
-    # add template by id
-    for my $StandardTemplateID ( @{$StandardTemplateID2QueueByCreating} ) {
-
-        $Self->QueueStandardTemplateMemberAdd(
-            QueueID            => $QueueID,
-            StandardTemplateID => $StandardTemplateID,
-            Active             => 1,
-            UserID             => $Param{UserID},
-        );
-    }
-
     return $QueueID;
 }
 
@@ -932,7 +903,7 @@ sub QueueAdd {
 get queue attributes
 
     my %Queue = $QueueObject->QueueGet(
-        ID    => 123,
+        ID => 123,
     );
 
     my %Queue = $QueueObject->QueueGet(
@@ -1083,8 +1054,8 @@ update queue attributes
         UserID              => 123,
         FollowUpID          => 1,
         Comment             => 'Some Comment2',
-        DefaultSignKey      => ''
-        UnlockTimeOut       => ''
+        DefaultSignKey      => '',
+        UnlockTimeOut       => '',
         FollowUpLock        => 1,
         ParentQueueID       => '',
     );
@@ -1198,6 +1169,11 @@ sub QueueUpdate {
         ],
     );
 
+    # reset cache
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+        Type => $Self->{CacheType},
+    );
+
     # get queue data with updated name for QueueUpdate event
     my %Queue = $Self->QueueGet( Name => $Param{Name} );
 
@@ -1211,11 +1187,6 @@ sub QueueUpdate {
         UserID => $Param{UserID},
     );
 
-    # reset cache
-    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
-        Type => $Self->{CacheType},
-    );
-
     # updated all sub queue names
     my @ParentQueue = split( /::/, $OldQueue{Name} );
 
@@ -1376,7 +1347,7 @@ return 1 if another queue with this name already exists
 
     $Exist = $QueueObject->NameExistsCheck(
         Name => 'Some::Queue',
-        ID => 1, # optional
+        ID   => 1,              # optional
     );
 
 =cut
